
# Major revisions

*ProMo uses semantic versioning (Major.Minor.Patch)*

Ver 2.0 (July 15, 2023)
- drop support for python 2.x

Ver 1.3 (May 29, 2017)
- added tutorials
- f0Morph() can now exclude certain regions from the morph process if desired

Ver 1.2 (January 27, 2017)
- added code for reshaping pitch accents (shift alignment, add plateau, or change height)

Ver 1.1 (February 22, 2016)
- f0 morph code for modifying speaker pitch range and average pitch
- (October 20, 2016) Added integration tests with travis CI and coveralls support.

Ver 1.0 (January 19, 2016)
- first public release.

Beta (July 1, 2013)
- first version which was utilized in my dissertation work
